@@ -2,7 +2,6 @@ from notification.backends.aliyunsms import (
     AliyunSMSNotificationBackend,
     notify_by_aliyun_sms,
 )
-from notification.backends.base import notify
 from notification.backends.dingchatbot import (
     DingTalkChatbotNotificationBackend,
     notify_by_dingtalk_chatbot,
@@ -21,6 +20,7 @@ from notification.backends.websocket import (
     WebsocketNotificationBackend,
     notify_by_websocket,
 )
+from notification.base import notify
 
 __all__ = [
     "notify",
