@@ -1,6 +1,6 @@
 from django.contrib.auth.models import User
 
-from notification.backends.base import BaseNotificationBackend, notify
+from notification.base import BaseNotificationBackend, notify
 from notification.models import Message
 
 
