@@ -5,7 +5,7 @@ from django.contrib.auth.models import User
 from django.core.mail import EmailMessage
 from django.template import Context, Template
 
-from notification.backends.base import BaseNotificationBackend, notify
+from notification.base import BaseNotificationBackend, notify
 from notification.models import Message, MessageTemplate
 
 
