@@ -17,7 +17,7 @@ def get_notification_backend(msg_type: str):
     Get notification backend.
     """
     from notification import backends
-    from notification.backends.base import BaseNotificationBackend
+    from notification.base import BaseNotificationBackend
 
     for att in dir(backends):
         attr_value = (att, getattr(backends, att))
